@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: mime-types
 version: 0.1.0.6
-id: mime-types-0.1.0.6-1ae582cd69235deb20f7c2577dd8b3dc
-key: mimet_Auf3arlsqyh1vk2EtUPwQu
+id: mime-types-0.1.0.6-7d5f22022675c00ea07fd0f1df020c2e
+key: mimet_9JBMcwv2Xiq5zZQuEgPby5
 license: MIT
 maintainer: michael@snoyman.com
 homepage: https://github.com/yesodweb/wai
@@ -19,12 +19,12 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.6
 library-dirs: /usr/lib/ghc-7.10.3/site-local/mime-types-0.1.0.6
 data-dir: /usr/share/arm-linux-ghc-7.10.3/mime-types-0.1.0.6
-hs-libraries: HSmime-types-0.1.0.6-Auf3arlsqyh1vk2EtUPwQu
+hs-libraries: HSmime-types-0.1.0.6-9JBMcwv2Xiq5zZQuEgPby5
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-mime-types/html/mime-types.haddock
 haddock-html: /usr/share/doc/haskell-mime-types/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
